## ---- echo=FALSE, fig.align='center', out.width='50%', fig.width=10, fig.height=6----
knots <- c(2,5,7.5)
maxX <- 11.5
minX <- -2
plot(NULL, xlim=c(minX,maxX+1), ylim=c(minX,knots[2]), axes=FALSE, ylab="u(x)", xlab="x")
axis(1, c("min(X)", expression(k[1]), expression(k[2]), expression(k[3]),
          "max(X)"), at=c(minX, knots, maxX))
curve(x*(x<=knots[1])+knots[1]*(x>knots[1]), minX, maxX, add=TRUE,lwd=2)
curve((x-knots[3])*(x>knots[3]), knots[3], maxX, add=TRUE, col=4, lty=4,lwd=2)
curve((x-knots[1])*(knots[1]<=x)*(x<=knots[2])+
      (knots[2]-knots[1])*(x>knots[2]), knots[1], maxX, add=TRUE, col=2, lty=2,lwd=2)
curve((x-knots[2])*(knots[2]<=x)*(x<=knots[3])+
      (knots[3]-knots[2])*(x>knots[3]), knots[2], maxX, add=TRUE, col=3, lty=3,lwd=2)
legend("topleft", c(expression(u[1](x)), expression(u[2](x)), expression(u[3](x)),
                    expression(u[4](x))), col=1:4, lty=1:4, bty='n')
box()

## -----------------------------------------------------------------------------
library(causalTLSE)
data(nsw)

## -----------------------------------------------------------------------------
model1 <- setModel(re78 ~ treat | ~ age + re75 + ed + married, data = nsw)

## -----------------------------------------------------------------------------
model0 <-  setModel(re78 ~ treat | ~ age + I(age^2) + re75 + ed * married,
                   data = nsw)

## -----------------------------------------------------------------------------
model1$knots1

## -----------------------------------------------------------------------------
quantile(nsw[nsw$treat==1,'re75'], c(.2,.4,.6,.8), type=1)

## -----------------------------------------------------------------------------
model1

## -----------------------------------------------------------------------------
data(simDat4)
model2 <- setModel(Y ~ Z | ~ X1 + X2 + X3 + X4, data = simDat4)
model2$knots0

## -----------------------------------------------------------------------------
setModel(re78 ~ treat | ~ age + re75 + ed + married, data = nsw,
         knots1 = NULL)

## -----------------------------------------------------------------------------
model <- setModel(re78 ~ treat | ~ age + re75 + ed + married, data = nsw,
                  knots0 = list(NA, c(1000,5000,10000), NULL, NA))

## -----------------------------------------------------------------------------
print(model, knots = TRUE)

## -----------------------------------------------------------------------------
knots <- list(married = NA, ed = NULL, 'age:ed' = NULL, 
              re75 = c(1000,5000,10000), age = NA)
model <- setModel(re78 ~ treat | ~ age * ed + re75 + married, data = nsw,
                  knots0 = knots)
model$knots0

## -----------------------------------------------------------------------------
knots <- list(ed = NULL, 'age:ed' = NULL, re75 = c(1000,5000,10000))
model <- setModel(re78 ~ treat | ~ age * ed + re75 + married, data = nsw,
                  knots0 = knots)
model$knots0

## -----------------------------------------------------------------------------
knots <- list('age:ed' = NULL, 'ed:re75' = NULL, 'ed:married' = NULL)
model <- setModel(re78 ~ treat | ~ age * ed + re75 * ed + married * ed, data = nsw,
                  knots0 = knots, knots1 = knots)
model

## -----------------------------------------------------------------------------
model <- setModel(re78 ~ treat | ~ age + ed * black, data = nsw)         
model$knots0[["ed:black"]]

## -----------------------------------------------------------------------------
model <- setModel(re78 ~ treat | ~ age + married, data = nsw,
                  nbasis = function(n) 2)
print(model, knots = TRUE)
fit <- estModel(model)
fit

## -----------------------------------------------------------------------------
summary(fit)

## -----------------------------------------------------------------------------
summary(fit$lm.out)[c("r.squared","adj.r.squared")]

## -----------------------------------------------------------------------------
predict(fit,
        newdata = data.frame(treat = c(1,1,0,0),age = 20:23, married = 1))

## -----------------------------------------------------------------------------
predict(fit,
        newdata = data.frame(treat = c(1,1,0,0),age = 20:23, married = 1),
        interval = "confidence")

## -----------------------------------------------------------------------------
predict(fit,
        newdata = data.frame(treat = c(1,1,0,0),age = 20:23, married = 1),
        se.fit = TRUE)$treated

## -----------------------------------------------------------------------------
model1 <- setModel(re78 ~ treat | ~ age + re75 + ed + married, data = nsw)
fit1 <- estModel(model1)

## ---- fig.show='hold', out.width='50%'----------------------------------------
library(sandwich)
plot(fit1, "ed", col0 = "darkgreen", col1 = "darkred", lty0 = 2, lty1 = 4,
     legendPos = "topleft", vcov. = vcov)
plot(fit1, "age", interval = 'confidence', level = 0.9, type = "HC1")

## ---- fig.show='hold', out.width='50%'----------------------------------------
plot(fit1, "age", FUN = median)
plot(fit1, "age", FUN = function(x) quantile(x, 0.20))

## ---- fig.show='hold', out.width='50%'----------------------------------------
plot(fit1, "age", fixedCov0 = list(married = 1, re75 = 10000),
     addToLegend = "married", cex = 0.8)
plot(fit1, "age", fixedCov0 = list(married = 0, re75 = 10000),
     addToLegend = "non-married", cex = 0.8)

## ---- fig.align='center', out.width='70%'-------------------------------------
plot(fit1, "age", fixedCov0 = list(married = 1, re75 = 10000),
     addToLegend = "married", cex = 0.8, ylim. = c(3000,10000))
plot(fit1, "age", fixedCov0 = list(married = 0, re75 = 10000),
     addToLegend = "non-married", cex = 0.8, legendPos = 'topleft',
     col0 = "darkgreen", col1 = "darkred", lty0 = 4, lty1 = 5,
     add. = TRUE)

## ---- fig.show='hold', out.width='50%'----------------------------------------
plot(fit1, "ed", col0 = "darkgreen", col1 = "darkred", lty0 = 2, lty1 = 4,
     legendPos = "topleft", addPoints = TRUE)
plot(fit1, "re75", addPoints = TRUE)

## -----------------------------------------------------------------------------
data(simDat4)
mod <- setModel(Y ~ Z | ~ X1 + X2 + X4, data = simDat4)
mod

## -----------------------------------------------------------------------------
data(simDat4)
mod <- setModel(Y ~ Z | ~ X1 + X2 * X4, data = simDat4)
mod

## ---- eval=FALSE--------------------------------------------------------------
#  fit <- estModel(mod)
#  plot(fit, "X1", fixedCov0 = list(X2 = "first"))

## -----------------------------------------------------------------------------
print(model1, knots = TRUE)
model2 <- selTLSE(model1)
print(model2, knots = TRUE)

## -----------------------------------------------------------------------------
model3 <- selTLSE(model1, selType = "BTLSE", selCrit = "BIC")
model3

## -----------------------------------------------------------------------------
estModel(selTLSE(model1, selType = "FTLSE", selCrit = "BIC"))

## -----------------------------------------------------------------------------
model1 <- setModel(re78 ~ treat | ~ age + re75 + ed + married, data=nsw)
fit1 <- estModel(model1)
causalTLSE(fit1)

## -----------------------------------------------------------------------------
ce <- causalTLSE(fit1)
summary(ce)

## -----------------------------------------------------------------------------
ce2 <- causalTLSE(fit1, seType="lm")
summary(ce2)

## ---- fig.align='center', out.width='65%'-------------------------------------
plot(ce2, "re75")

## ---- eval=FALSE--------------------------------------------------------------
#  library(texreg)
#  c1 <- causalTLSE(fit1)
#  fit2 <- estModel(selTLSE(model1, selType="BTLSE"))
#  fit3 <- estModel(selTLSE(model1, selType="FTLSE"))
#  c2 <- causalTLSE(fit2)
#  c3 <- causalTLSE(fit3)
#  texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table=FALSE, digits=4)

## ---- results='asis', message=FALSE, echo=FALSE-------------------------------
library(texreg)
c1 <- causalTLSE(fit1)
fit2 <- estModel(selTLSE(model1, selType="BTLSE"))
fit3 <- estModel(selTLSE(model1, selType="FTLSE"))
c2 <- causalTLSE(fit2)
c3 <- causalTLSE(fit3)
texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table=FALSE, digits=4)

## ---- eval=FALSE--------------------------------------------------------------
#  texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table=FALSE,
#         which="ACE-ACT", include.adjrsquared=FALSE)

## ---- results='asis', message=FALSE, echo=FALSE-------------------------------
texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table=FALSE,
       which="ACE-ACT", include.adjrsquared=FALSE)

## ---- eval=FALSE--------------------------------------------------------------
#  c1 <- causalTLSE(model1, selType="SLSE")
#  c2 <- causalTLSE(model1, selType="BTLSE")
#  c3 <- causalTLSE(model1, selType="FTLSE")
#  texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table=FALSE, digits=4)

## ---- results='asis', message=FALSE, echo=FALSE-------------------------------
c1 <- causalTLSE(model1, selType="SLSE")
c2 <- causalTLSE(model1, selType="BTLSE")
c3 <- causalTLSE(model1, selType="FTLSE")
texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table=FALSE, digits=4)

## ---- eval=FALSE--------------------------------------------------------------
#  c1 <- causalTLSE(re78 ~ treat | ~ age + re75 + ed + married, data=nsw,
#                   selType="SLSE")
#  c2 <- causalTLSE(re78 ~ treat | ~ age + re75 + ed + married, data=nsw,
#                   selType="BTLSE")
#  c3 <- causalTLSE(re78 ~ treat | ~ age + re75 + ed + married, data=nsw,
#                   selType="FTLSE")
#  texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table=FALSE, digits=4)

## ---- results='asis', message=FALSE, echo=FALSE-------------------------------
c1 <- causalTLSE(model1, selType = "SLSE")
c2 <- causalTLSE(model1, selType = "BTLSE")
c3 <- causalTLSE(model1, selType = "FTLSE")
texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table = FALSE, digits = 4)

## -----------------------------------------------------------------------------
data(simDat1)
mod <- setModel(Y ~ Z | ~ X, data = simDat1)

## ---- eval=FALSE--------------------------------------------------------------
#  c1 <- causalTLSE(mod, selType = "SLSE")
#  c2 <- causalTLSE(mod, selType = "BTLSE", selCrit = "BIC")
#  c3 <- causalTLSE(mod, selType = "FTLSE", selCrit = "BIC")
#  texreg(list(SLSE = c1, BTLSE = c2, FTLSE = c3), table = FALSE, digits = 4)

## ---- results='asis', message=FALSE, echo=FALSE-------------------------------
c1 <- causalTLSE(mod, selType = "SLSE")
c2 <- causalTLSE(mod, selType = "BTLSE", selCrit = "BIC")
c3 <- causalTLSE(mod, selType = "FTLSE", selCrit = "BIC")
texreg(list(SLSE = c1, BTLSE = c2, FTLSE = c3), table = FALSE, digits = 4)

## ---- out.width='50%', fig.show='hold'----------------------------------------
plot(c1, "X")
curve(1 - 2 * x, -3, 3, col = "darkgreen", lty = 4, lwd = 3, add = TRUE)
curve(1 + x + x^2, -3, 3, col = "darkorange", lty = 4, lwd = 3, add = TRUE)
legend("bottomleft", c("True-treated", "True-nontreated"),
       col=c("darkgreen", "darkorange"), lty = 4, lwd = 3, bty = 'n')
plot(c2, "X")
curve(1 - 2 * x, -3, 3, col="darkgreen", lty = 4, lwd = 3, add = TRUE)
curve(1 + x + x^2, -3, 3, col = "darkorange", lty = 4, lwd = 3, add = TRUE)
legend("bottomleft", c("True-treated", "True-nontreated"),
       col = c("darkgreen", "darkorange"), lty = 4, lwd = 3, bty = 'n')

## ---- out.width='60%', fig.align='center'-------------------------------------
plot(c1, "X", addPoints=TRUE)

## -----------------------------------------------------------------------------
data(simDat2)
mod <- setModel(Y~Z | ~X, data=simDat2)

## ---- eval=FALSE--------------------------------------------------------------
#  c1 <- causalTLSE(mod, selType = "SLSE")
#  c2 <- causalTLSE(mod, selType = "BTLSE", selCrit = "BIC")
#  c3 <- causalTLSE(mod, selType = "BTLSE", selCrit = "AIC")
#  texreg(list(SLSE = c1, BTLSE.BIC = c2, BTLSE.AIC = c3), table = FALSE, digits = 4)

## ---- results='asis', message=FALSE, echo=FALSE-------------------------------
c1 <- causalTLSE(mod, selType = "SLSE")
c2 <- causalTLSE(mod, selType = "BTLSE", selCrit = "BIC")
c3 <- causalTLSE(mod, selType = "BTLSE", selCrit = "AIC")
texreg(list(SLSE = c1, BTLSE.BIC = c2, BTLSE.AIC = c3), table = FALSE, digits = 4)

## ---- out.width='50%', fig.show='hold'----------------------------------------
plot(c2, "X", legendPos = "right", cex = .8)
curve((1 -2 * x) * (x <= 0) + (1 + 2 * x) * (x > 0), -3, 3,
      col = "darkgreen", lty = 3, lwd = 3, add = TRUE)
curve((1 + x) * (x <= -1) + (-1 - x) * (x > -1),
      -3, 3, col = "darkorange", lty = 3, lwd = 3, add = TRUE)
legend("left", c("True-treated", "True-nontreated"),
       col = c("darkgreen", "darkorange"), lty = 3, lwd = 3, bty = 'n', cex = .8)
plot(c2, "X", addPoints = TRUE, legendPos = "topleft", cex = .8)

## -----------------------------------------------------------------------------
data(simDat3)
mod <- setModel(Y ~ Z | ~ X1 + X2, data = simDat3)

## ---- eval=FALSE--------------------------------------------------------------
#  c1 <- causalTLSE(mod, selType = "SLSE")
#  c2 <- causalTLSE(mod, selType = "FTLSE", selCrit = "BIC")
#  c3 <- causalTLSE(mod, selType = "FTLSE", selCrit = "AIC")
#  texreg(list(SLSE = c1, FTLSE.BIC = c2, FTLSE.AIC = c3), table = FALSE, digits = 4)

## ---- results='asis', message=FALSE, echo=FALSE-------------------------------
c1 <- causalTLSE(mod, selType = "SLSE")
c2 <- causalTLSE(mod, selType = "FTLSE", selCrit = "BIC")
c3 <- causalTLSE(mod, selType = "FTLSE", selCrit = "AIC")
texreg(list(SLSE = c1, FTLSE.BIC = c2, FTLSE.AIC = c3), table = FALSE, digits = 4)

## ---- out.width='50%', fig.show='hold'----------------------------------------
plot(c2, "X1", legendPos = "right", cex = .8)
curve(x + x^2, -3, 3, col = "darkgreen", lty = 3, lwd = 3, add = TRUE)
curve(2 - 2 * x, -3, 3, col = "darkorange", lty = 3, lwd = 3, add = TRUE)
legend("topleft", c("True-treated", "True-nontreated"),
       col = c("darkgreen", "darkorange"), lty = 3, lwd = 3, bty = 'n', cex = .8)
plot(c2, "X1", addPoints = TRUE, legendPos = "topleft", cex = .8)

## ---- out.width='50%', fig.show='hold'----------------------------------------
plot(c2, "X2", legendPos = "right", cex = .8)
curve(1 + (1 - 2 * x) * (x <= 0) + (1 + 2 * x) * (x > 0), -3, 3,
      col = "darkgreen", lty = 3, lwd = 3, add = TRUE)
curve(1 + (1 + x) * (x <= -1) + (-1 - x) * (x > -1),
      -3, 3, col = "darkorange", lty = 3, lwd = 3, add = TRUE)
legend("left", c("True-treated", "True-nontreated"),
       col = c("darkgreen", "darkorange"), lty = 3, lwd = 3, bty = 'n', cex = .8)
plot(c2, "X2", addPoints = TRUE, legendPos = "topleft", cex = .8)

## ---- echo=FALSE--------------------------------------------------------------
sim_model <- function(n)
{
	X1 <- rnorm(n)
    X2 <- rnorm(n)
	probX <- plogis(1 + X1 + X2 + X1*X2) 
	Z <- rbinom(n, 1, probX)
	er0 <- rnorm(n)
	er1 <- rnorm(n)
	Y0 <-  (1 + X1 + X1^2) + (1 + X2)  * (X2 <= -1) + 
		(-1 - X2) * (X2 > -1) + (1+X1*X2 + X1^2*X2^2) + er0
	Y1 <- (1 - 2*X1) + (1 - 2*X2)*(X2 <= 0) + 
		(1 + 2*X2) * (X2 > 0) + (1-2*X1*X2) + er1
	Y <- Y0 * (1 - Z) + Y1 * Z
	data.frame(Y=Y, X1=X1, X2=X2, Z=Z, Y1=Y1, Y0=Y0)
}

## -----------------------------------------------------------------------------
data(simDat5)
mod <- setModel(Y ~ Z | ~ X1 * X2, data = simDat5)

## ---- eval=FALSE--------------------------------------------------------------
#  c1 <- causalTLSE(mod, selType = "SLSE")
#  c2 <- causalTLSE(mod, selType = "FTLSE", selCrit = "BIC")
#  c3 <- causalTLSE(mod, selType = "FTLSE", selCrit = "AIC")
#  texreg(list(SLSE = c1, FTLSE.BIC = c2, FTLSE.AIC = c3), table = FALSE, digits = 4)

## ---- results='asis', message=FALSE, echo=FALSE-------------------------------
c1 <- causalTLSE(mod, selType="SLSE")
c2 <- causalTLSE(mod, selType="FTLSE", selCrit="BIC")
c3 <- causalTLSE(mod, selType="FTLSE", selCrit="AIC")
texreg(list(SLSE=c1, FTLSE.BIC=c2, FTLSE.AIC=c3), table=FALSE, digits=4)

## ---- out.width='50%', fig.show='hold'----------------------------------------
x20 <- mean(subset(simDat5, Z == 0)$X2)
x21 <- mean(subset(simDat5, Z == 1)$X2)
plot(c2, "X1", fixedCov0 = list(X2 = x20), fixedCov1 = list(X2 = x21),
     legendPos = "right", cex = .8,
     main="Y vs X1 (X2 = sample mean for each group)")
curve(1.3698 + 0.6302 * x + 1.1368 * x^2, -3, 3,
      col = "darkgreen", lty = 3, lwd = 3, add = TRUE)
curve(3.3964 - 2.3964 * x, -3, 3, col = "darkorange", lty = 3, lwd = 3, add = TRUE)
legend("top", c("True-treated", "True-nontreated"),
       col=c("darkorange", "darkgreen"), lty = 3, lwd = 3, bty = 'n', cex = .8)
plot(c2, "X1", fixedVoc0 = list(X2 = 1), legendPos = "right", cex = .8,
     main="Y vS X1 (X2 = 1 for each group)")
curve(2 * x + 2 * x^2, -3, 3, col = "darkgreen", lty = 3, lwd = 3, add = TRUE)
curve(5 - 4 * x, -3, 3, col = "darkorange", lty = 3, lwd = 3, add = TRUE)
legend("top", c("True-treated", "True-nontreated"),
       col = c("darkgreen", "darkorange"), lty = 3, lwd = 3, bty = 'n', cex = .8)

## ---- out.width='50%', fig.show='hold'----------------------------------------
x10 <- mean(subset(simDat5, Z == 0)$X1)
x11 <- mean(subset(simDat5, Z == 1)$X1)
plot(c2, "X2", fixedCov0 = list(X1 = x10), fixedCov1 = list(X1 = x11),
     legendPos = "right", cex = .8,
     main = "Y vs X2 (X1 = sample mean for each group)")
curve(1.603900 - .3964 * x + (1 - 2 * x) * (x <= 0) + (1 + 2 * x) * (x > 0), -3, 3,
      col = "darkgreen", lty = 3, lwd = 3, add = TRUE)
curve(1.767 - 0.3698 * x + 0.1368 * x^2 + (1 + x) * (x <= -1) + (-1 - x) * (x > -1),
      -3, 3, col = "darkorange", lty = 3, lwd = 3, add = TRUE)
legend("top", c("True-treated", "True-nontreated"),
       col = c("darkorange", "darkgreen"), lty = 3, lwd = 3, bty = 'n', cex = .8)
plot(c2, "X2", fixedCov0 = list(X1 = 1), legendPos = "right", cex = .8,
     main="Y vS X2 (X1 = 1 for each group)")
curve(-2 * x + (1 - 2 * x) * (x <= 0) + (1 + 2 * x) * (x > 0), -3, 3,
      col = "darkgreen", lty = 3, lwd = 3, add = TRUE)
curve(4 + (1 + x) * (x <= -1) + (-1 - x) * (x > -1) + x + x^2,
      -3, 3, col = "darkorange", lty = 3, lwd = 3, add = TRUE)
legend("top", c("True-treated", "True-nontreated"),
       col = c("darkgreen", "darkorange"), lty = 3, lwd = 3, bty = 'n', cex = .8)

